import './boot.js';
import { pathFromUrl } from './resolve-url.js';

const settings = undefined || {};
settings.useShadow = !(window.ShadyDOM);
settings.useNativeCSSProperties =
  Boolean(!window.ShadyCSS || window.ShadyCSS.nativeCss);
settings.useNativeCustomElements =
  !(window.customElements.polyfillWrapFlushCallback);

/**
 * Sets the global, legacy settings.
 *
 * @deprecated
 * @namespace
 * @memberof Polymer
 */
Polymer.Settings = settings;

/**
 * Globally settable property that is automatically assigned to
 * `Polymer.ElementMixin` instances, useful for binding in templates to
 * make URL's relative to an application's root.  Defaults to the main
 * document URL, but can be overridden by users.  It may be useful to set
 * `Polymer.rootPath` to provide a stable application mount path when
 * using client side routing.
 *
 * @memberof Polymer
 */
let rootPath = undefined ||
  pathFromUrl(document.baseURI || window.location.href);

export { rootPath };

export const setRootPath = function(path) {
  rootPath = path;
};

/**
 * A global callback used to sanitize any value before inserting it into the DOM. The callback signature is:
 *
 *     Polymer = {
 *       sanitizeDOMValue: function(value, name, type, node) { ... }
 *     }
 *
 * Where:
 *
 * `value` is the value to sanitize.
 * `name` is the name of an attribute or property (for example, href).
 * `type` indicates where the value is being inserted: one of property, attribute, or text.
 * `node` is the node where the value is being inserted.
 *
 * @type {(function(*,string,string,Node):*)|undefined}
 * @memberof Polymer
 */
let sanitizeDOMValue = undefined;

export { sanitizeDOMValue };

export const setSanitizeDOMValue = function(newSanitizeDOMValue) {
  sanitizeDOMValue = newSanitizeDOMValue;
};

/**
 * Globally settable property to make Polymer Gestures use passive TouchEvent listeners when recognizing gestures.
 * When set to `true`, gestures made from touch will not be able to prevent scrolling, allowing for smoother
 * scrolling performance.
 * Defaults to `false` for backwards compatibility.
 *
 * @memberof Polymer
 */
let passiveTouchGestures = false;

export { passiveTouchGestures };

export const setPassiveTouchGestures = function(usePassive) {
  passiveTouchGestures = usePassive;
};
