"use strict";
/**
 * @license
 * Copyright (c) 2018 The Polymer Project Authors. All rights reserved.
 * This code may only be used under the BSD style license found at
 * http://polymer.github.io/LICENSE.txt
 * The complete set of authors may be found at
 * http://polymer.github.io/AUTHORS.txt
 * The complete set of contributors may be found at
 * http://polymer.github.io/CONTRIBUTORS.txt
 * Code distributed by Google as part of the polymer project is also
 * subject to an additional IP rights grant found at
 * http://polymer.github.io/PATENTS.txt
 */
Object.defineProperty(exports, "__esModule", { value: true });
const fse = require("fs-extra");
const os_1 = require("os");
const nodeModulesLine = 'node_modules';
const searchNodeModulesLine = new RegExp(`^/?${nodeModulesLine}`);
async function ignoreNodeModules(ignoreFile) {
    let ignoreLines = [];
    if (await fse.pathExists(ignoreFile)) {
        const content = await fse.readFile(ignoreFile, 'utf-8');
        ignoreLines = content.split(os_1.EOL);
    }
    const hasNodeModules = ignoreLines.some((line) => {
        return searchNodeModulesLine.test(line);
    });
    if (hasNodeModules) {
        return;
    }
    ignoreLines.push(nodeModulesLine);
    const outContent = ignoreLines.join(os_1.EOL) + os_1.EOL;
    await fse.writeFile(ignoreFile, outContent);
}
exports.ignoreNodeModules = ignoreNodeModules;
//# sourceMappingURL=gitignore.js.map